==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/id.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "The mountpoint name contains invalid characters." : "Nama mount point berisi karakter yang tidak sah.",
    "Invalid or untrusted SSL certificate" : "Sertifikast SSL tidak sah atau tidak terpercaya",
    "Could not authenticate to remote share, password might be wrong" : "Tidak dapat mengautentikasi berbagi remote, kata sandi mungkin salah",
    "Storage not valid" : "Penyimpanan tidak sah",
    "Couldn't add remote share" : "Tidak dapat menambahkan berbagi remote",
    "Shared with you" : "Dibagikan dengan Anda",
    "Shared with others" : "Dibagikan dengan lainnya",
    "Shared by link" : "Dibagikan dengan tautan",
    "Nothing shared with you yet" : "Tidak ada yang dibagikan kepada Anda",
    "Files and folders others share with you will show up here" : "Berkas dan folder lainnya yang dibagikan kepada Anda akan ditampilkan disini",
    "Nothing shared yet" : "Tidak ada yang dibagikan",
    "Files and folders you share will show up here" : "Berkas dan folder yang Anda bagikan akan ditampilkan disini",
    "No shared links" : "Tidak ada tautan berbagi",
    "Files and folders you share by link will show up here" : "Berkas dan folder yang Anda bagikan menggunakan tautan akan ditampilkan disini",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan berbagi remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Sandi berbagi remote",
    "Cancel" : "Batal",
    "Add remote share" : "Tambah berbagi remote",
    "No ownCloud installation (7 or higher) found at {remote}" : "Tidak ditemukan instalasi ownCloud (7 atau lebih tinggi) pada {remote}",
    "Invalid ownCloud url" : "URL ownCloud tidak sah",
    "Share" : "Bagikan",
    "Shared by" : "Dibagikan oleh",
    "A file or folder has been <strong>shared</strong>" : "Sebuah berkas atau folder telah <strong>dibagikan</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Sebuah berkas atau folder telah dibagikan dari <strong>server lainnya</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Sebuah berkas atau folder berbagi publik telah <strong>diunduh</strong>",
    "You received a new remote share from %s" : "Anda menerima berbagi remote baru dari %s",
    "%1$s accepted remote share %2$s" : "%1$s menerima berbagi remote %2$s",
    "%1$s declined remote share %2$s" : "%1$s menolak berbagi remote %2$s",
    "%1$s unshared %2$s from you" : "%1$s menghapus berbagi %2$s dari Anda",
    "Public shared folder %1$s was downloaded" : "Folder berbagi publik %1$s telah diunduh",
    "Public shared file %1$s was downloaded" : "Berkas berbagi publik %1$s telah diunduh",
    "You shared %1$s with %2$s" : "Anda membagikan %1$s dengan %2$s",
    "You shared %1$s with group %2$s" : "Anda membagikan %1$s dengan grup %2$s",
    "%2$s shared %1$s with you" : "%2$s membagikan %1$s dengan Anda",
    "You shared %1$s via link" : "Anda membagikan %1$s via tautan",
    "Shares" : "Dibagikan",
    "This share is password-protected" : "Berbagi ini dilindungi sandi",
    "The password is wrong. Try again." : "Sandi salah. Coba lagi",
    "Password" : "Sandi",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Share time" : "Waktu berbagi",
    "Sorry, this link doesn’t seem to work anymore." : "Maaf, tautan ini tampaknya tidak berfungsi lagi.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the item was removed" : "item telah dihapus",
    "the link expired" : "tautan telah kadaluarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more info, please ask the person who sent this link." : "Untuk info lebih lanjut, silakan tanyakan orang yang mengirim tautan ini.",
    "Add to your ownCloud" : "Tambahkan ke ownCloud Anda",
    "Download" : "Unduh",
    "Download %s" : "Unduh %s",
    "Direct link" : "Tautan langsung",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Buka dokumentasi",
    "Allow users on this server to send shares to other servers" : "Izinkan para pengguna di server ini untuk mengirimkan berbagi ke server lainnya.",
    "Allow users on this server to receive shares from other servers" : "Izinkan para pengguna di server ini untuk menerima berbagi ke server lainnya."
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/id.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "The mountpoint name contains invalid characters." : "Nama mount point berisi karakter yang tidak sah.",
    "Invalid or untrusted SSL certificate" : "Sertifikast SSL tidak sah atau tidak terpercaya",
    "Could not authenticate to remote share, password might be wrong" : "Tidak dapat mengautentikasi berbagi remote, kata sandi mungkin salah",
    "Storage not valid" : "Penyimpanan tidak sah",
    "Couldn't add remote share" : "Tidak dapat menambahkan berbagi remote",
    "Shared with you" : "Dibagikan dengan Anda",
    "Shared with others" : "Dibagikan dengan lainnya",
    "Shared by link" : "Dibagikan dengan tautan",
    "Uploading..." : "Mengunggah...",
    "Nothing shared with you yet" : "Tidak ada yang dibagikan kepada Anda",
    "Files and folders others share with you will show up here" : "Berkas dan folder lainnya yang dibagikan kepada Anda akan ditampilkan disini",
    "Nothing shared yet" : "Tidak ada yang dibagikan",
    "Files and folders you share will show up here" : "Berkas dan folder yang Anda bagikan akan ditampilkan disini",
    "No shared links" : "Tidak ada tautan berbagi",
    "Files and folders you share by link will show up here" : "Berkas dan folder yang Anda bagikan menggunakan tautan akan ditampilkan disini",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan berbagi remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Sandi berbagi remote",
    "Cancel" : "Batal",
    "Add remote share" : "Tambah berbagi remote",
    "You can upload into this folder" : "Anda dapat mengunggah kedalam folder ini",
    "No ownCloud installation (7 or higher) found at {remote}" : "Tidak ditemukan instalasi ownCloud (7 atau lebih tinggi) pada {remote}",
    "Invalid ownCloud url" : "URL ownCloud tidak sah",
    "Share" : "Bagikan",
    "Shared by" : "Dibagikan oleh",
    "Sharing" : "Berbagi",
    "A file or folder has been <strong>shared</strong>" : "Sebuah berkas atau folder telah <strong>dibagikan</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Sebuah berkas atau folder telah dibagikan dari <strong>server lainnya</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Sebuah berkas atau folder berbagi publik telah <strong>diunduh</strong>",
    "You received a new remote share %2$s from %1$s" : "Anda menerima berbagi remote baru %2$s dari %1$s",
    "You received a new remote share from %s" : "Anda menerima berbagi remote baru dari %s",
    "%1$s accepted remote share %2$s" : "%1$s menerima berbagi remote %2$s",
    "%1$s declined remote share %2$s" : "%1$s menolak berbagi remote %2$s",
    "%1$s unshared %2$s from you" : "%1$s menghapus berbagi %2$s dari Anda",
    "Public shared folder %1$s was downloaded" : "Folder berbagi publik %1$s telah diunduh",
    "Public shared file %1$s was downloaded" : "Berkas berbagi publik %1$s telah diunduh",
    "You shared %1$s with %2$s" : "Anda membagikan %1$s dengan %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s berbagi %1$s kepada %3$s",
    "You shared %1$s with group %2$s" : "Anda membagikan %1$s dengan grup %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s berbagi %1$s kepada grup %3$s",
    "%2$s shared %1$s via link" : "%2$s berbagi %1$s via tautan",
    "You shared %1$s via link" : "Anda membagikan %1$s via tautan",
    "%2$s shared %1$s with you" : "%2$s membagikan %1$s dengan Anda",
    "Downloaded via public link" : "Diunduh via tautan publik",
    "Shared with %2$s" : "Dibagikan kepada %2$s",
    "Shared with %3$s by %2$s" : "Dibagikan kepada %3$s oleh %2$s",
    "Shared with group %2$s" : "Dibagikan kepada grup %2$s",
    "Shared with group %3$s by %2$s" : "Dibagikan kepada grup %3$s oleh %2$s",
    "Shared via link by %2$s" : "Dibagikan via tautan oleh %2$s",
    "Shared via public link" : "Dibagikan via tautan publik",
    "Shared by %2$s" : "Dibagikan oleh %2$s",
    "Shares" : "Dibagikan",
    "This share is password-protected" : "Berbagi ini dilindungi sandi",
    "The password is wrong. Try again." : "Sandi salah. Coba lagi",
    "Password" : "Sandi",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Name" : "Nama",
    "Share time" : "Waktu berbagi",
    "Expiration date" : "Tanggal kedaluwarsa",
    "Sorry, this link doesn’t seem to work anymore." : "Maaf, tautan ini tampaknya tidak berfungsi lagi.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the item was removed" : "item telah dihapus",
    "the link expired" : "tautan telah kadaluarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more info, please ask the person who sent this link." : "Untuk info lebih lanjut, silakan tanyakan orang yang mengirim tautan ini.",
    "Add to your ownCloud" : "Tambahkan ke ownCloud Anda",
    "Download" : "Unduh",
    "Download %s" : "Unduh %s",
    "Direct link" : "Tautan langsung"
},
"nplurals=1; plural=0;");
